## Ust_DEanalysis_v1_Jan2019
## Teeratas Kijpornyongpan
## 8 Jan 2019
## Perform differential gene expression analyses across two Ustilaginomycotina species
## Meimi and Tilwa --> treatment between Glucose (yeast) and Tween40 (hyphal)
## Then, go for Ustma -->Tollot2016 and Lanver2018

source("http://bioconductor.org/biocLite.R")

#load packages we will need
#BiocInstaller::biocLite("DESeq2")
 library('DESeq2')  ##Load DESeq2_1.20.0
# library('Biobase')
#BiocInstaller::biocLite("DESeq")
 library('DESeq')   ##Load DESeq_1.32.0
 #detach("package:DESeq")
#BiocInstaller::biocLite("genefilter")
 library('genefilter') ##Load genefilter_1.62.0
#install.packages("gplots")
 library('gplots')   ##Load gplots_3.0.1
#BiocInstaller::biocLite("vsn")
 library("vsn")       ##Load vsn_3.48.1
#BiocInstaller::biocLite("pheatmap")
 library("pheatmap")  ##Load pheatmap_1.0.12
library("ggplot2")    ##Load ggplot2_3.1.0
library(shiny)        ##Load shiny_1.2.0
#BiocInstaller::biocLite("impute")
 library("impute")    ##Load impute_1.54.0
 library(shinyFiles)  ##Load shinyFile_0.7.2
 library(RColorBrewer)

setwd("../MCA3882_4186_RawReadCount/")
#######################DESeq2 workflow#######################################################
##### Start from Meimi dataset #####
#Start from loading raw read count files
data<-read.table("MCA3882_RawReadCount.txt",header=TRUE)
#create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-5):nrow(data)),-1]

#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #7400 x 6, 7400 genes in 6 samples 

#set a matrix showing an experimental design, make sure to use consistant library name
samples <- data.frame(row.names=c("MCA3882_G.R1", "MCA3882_G.R3", "MCA3882_G.R5", "MCA3882_T.R2", "MCA3882_T.R3", "MCA3882_T.R6"),
                      treatment=as.factor(c(rep("G",3), rep("T",3))), replicate=as.factor(rep(1:3, 2)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)

countData<-counts(data)
head(countData)
##make sure to include potential interactions in the model
##specify design formula, which includes the variables which will be used in modeling
##the design formula is used in estimating the dispersions and the log2 fold changes of the model
#dds<- DESeqDataSetFromMatrix(countData = countData,
#                             colData = colData,
#                             design =~ cellSubtype*condition)

##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)

dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## T.R2 and T.R6 have smaller library size than the others.
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)

write.csv(counts(dds, normalized=TRUE),file="MCA3882_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
hist(counts(data[,1]))
min(counts(data[,1]))
max(counts(data[,1]))

##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 2:3] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,4)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,6)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))

#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
#In this case dd$group levels: G T --> when doing results() as a default --> will be T vs G --> log2(T/G)
res <- results(dds,contrast=c("group","T","G"))
write.csv(res,file="MCA3882_DESeq2ResultsStats.txt")
#order results table by the smallest adjusted p value
resOrdered <- res[order(res$padj),]
#summarize results
summary(res)

##by default, alpha is set to 0.1; do again, using alpha=0.05
##contrast statements to state specifically what we want to test
##This case, there is only two treatments so no contrast is needed.
# resGT<-results(dds,contrast=c("group","T","G"),alpha=0.05)
# summary(resGT)
# write.csv(resGT,file="MCA3882_DESeq2ResultsStats_AlphaFivePercent.txt")
# #get info about which variables and tests were used (can do for any of the above tests)
# mcols(resGT)$description

write.csv(as.data.frame(resOrdered),
          file="MCA3882_DESeq2Results_sorted.csv")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
par( mfrow = c(1, 2))
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )

#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Make the heatmap for two factors like Nadia's script. But this case I have only one factor
  #df <- as.data.frame(colData(dds)[,c("treatment","replicate")])
  #pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
  #         cluster_cols=FALSE, annotation_col=df)
##Try making heatmap for only one factor, but the script may not be so neat.
  df <- as.data.frame(colData(dds)[, "treatment"])
  rownames(df) <- rownames(colData(dds))
  colnames(df) <- "treatment"
  pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
           cluster_cols=FALSE, annotation_col=df,cex=0.8)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  

#plot dispersions.  gene-wise dispersions are in black, fitted values in red
par( mfrow = c(1, 1))
plotDispEsts(dds)   ##this function is in DESEq2 package

#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))

#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="T40 vs Glucose", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
##When making four panels, like the original script
# par(mfrow=c(2,2),mar=c(2,2,1,1)+0.1)
# par(oma=c(4,4,0,0) )
# DESeq2::plotMA(res, main="Glucose vs T40", ylim=yl, xlab='Mean Expression', ylab='logFC')
# abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
# mtext('Mean Expression', side = 1, outer = TRUE, line = 2)
# mtext('logFC', side = 2, outer = TRUE, line = 2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value

library('DESeq2')

#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")


#############################################################################################
##### Next, go for Tilwa dataset #####
#Start from loading raw read count files
data<-read.table("../Ust_Illumina/MCA3882_4186_RawReadCount/MCA4186_RawReadCount.txt",header=TRUE)
#create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-5):nrow(data)),-1]
dim(countMatrix)    #7011 x 8

#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #6999 x 8, 6999 genes in 8 samples 

#set a matrix showing an experimental design, make sure to use consistant library name
samples <- data.frame(row.names=c("MCA4186_G.R2", "MCA4186_G.R3", "MCA4186_G.R4", "MCA4186_G.R5", "MCA4186_T.R2", "MCA4186_T.R3",
                                  "MCA4186_T.R4", "MCA4186_T.R5"),
                      treatment=as.factor(c(rep("G",4), rep("T",4))), replicate=as.factor(rep(1:4, 2)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)

countData<-counts(data)
head(countData)
##make sure to include potential interactions in the model
##specify design formula, which includes the variables which will be used in modeling
##the design formula is used in estimating the dispersions and the log2 fold changes of the model
#dds<- DESeqDataSetFromMatrix(countData = countData,
#                             colData = colData,
#                             design =~ cellSubtype*condition)

##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)

dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## T.R5 has smaller library size than the others. G.R2-G.R5 have small sizes too
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)

write.csv(counts(dds, normalized=TRUE),file="MCA4186_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
# hist(counts(data[,1]))
# min(counts(data[,1]))
# max(counts(data[,1]))

##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 3:4] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(7,8)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,7)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,7)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))

#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
#In this case dd$group levels: G, T --> when doing results() as a default --> will be T vs G --> log2(T/G)
res <- results(dds)
write.csv(res,file="Tilwa_DESeq2ResultsStats.txt", quote=FALSE)
#order results table by the smallest adjusted p value
resOrdered <- res[order(res$padj),]
#summarize results
summary(res)

##by default, alpha is set to 0.1; do again, using alpha=0.05
##contrast statements to state specifically what we want to test
##This case, there is only two treatments so no contrast is needed.
# resGT<-results(dds,contrast=c("group","T","G"),alpha=0.05)
# summary(resGT)
# write.csv(resGT,file="MCA3882_DESeq2ResultsStats_AlphaFivePercent.txt")
# #get info about which variables and tests were used (can do for any of the above tests)
# mcols(resGT)$description

write.csv(as.data.frame(resOrdered),
          file="Tilwa_DESeq2Results_sorted.csv", quote=FALSE)

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
# par( mfrow = c(1, 2))
# plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
# plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )
# par( mfrow = c(1, 1))

#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Make the heatmap for two factors like Nadia's script. But this case I have only one factor
#df <- as.data.frame(colData(dds)[,c("treatment","replicate")])
#pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
#         cluster_cols=FALSE, annotation_col=df)
##Try making heatmap for only one factor, but the script may not be so neat.
df <- as.data.frame(colData(dds)[, "treatment"])
rownames(df) <- rownames(colData(dds))
colnames(df) <- "treatment"
pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
         cluster_cols=FALSE, annotation_col=df, cex=0.9)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  

#plot dispersions.  gene-wise dispersions are in black, fitted values in red
plotDispEsts(dds)   ##this function is in DESEq2 package

#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))

#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="T40 vs Glucose", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
##When making four panels, like the original script
# par(mfrow=c(2,2),mar=c(2,2,1,1)+0.1)
# par(oma=c(4,4,0,0) )
# DESeq2::plotMA(res, main="Glucose vs T40", ylim=yl, xlab='Mean Expression', ylab='logFC')
# abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
# mtext('Mean Expression', side = 1, outer = TRUE, line = 2)
# mtext('logFC', side = 2, outer = TRUE, line = 2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value

library('DESeq2')

#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")

#############################################################################################
##### Next, go for Ustma dataset #####
##### Start from the study of Tollot et al. 2016 #####
setwd("../Umaydis/Tollot2016")

data<-read.table("./RawReadCount/Tollot2016RawReadCount.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #6717 x 6, 6717 genes in 6 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("wt_rep1", "wt_rep2", "wt_rep3", "ros1_rep1", "ros1_rep2", "ros1_rep3"),
                      treatment=as.factor(c(rep("wt",3), rep("ros1",3))), replicate=as.factor(rep(1:3, 2)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## ros1_rep1 has a smaller library size than the others, while wt_rep1 has the largest
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Tollot2016_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
hist(counts(data[,1]))
min(counts(data[,1]))
max(counts(data[,1]))
##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 2:3] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,4)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,6)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))
#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
#In this case dds$group levels: ros1 wt, so the default of dds$group --> log2(wt/ros1)
#If I want log2(hyphae/yeast) --> needs to do results(dds, contrast=c("group", "ros1", "wt"))
res <- results(dds, contrast=c("group", "ros1", "wt"))
write.csv(res,file="Tollot2016_DESeq2ResultsStats.txt")
#order results table by the smallest adjusted p value
resOrdered <- res[order(res$padj),]
#summarize results
summary(res)  ##Only 19.3% is differentially expressed, is it because of low number of read counts at the beginning?
write.csv(as.data.frame(resOrdered),
          file="Tollot2016_DESeq2Results_sorted.csv")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
par( mfrow = c(1, 2))
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )

#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Make the heatmap for two factors like Nadia's script. But this case I have only one factor
#df <- as.data.frame(colData(dds)[,c("treatment","replicate")])
#pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
#         cluster_cols=FALSE, annotation_col=df)
##Try making heatmap for only one factor, but the script may not be so neat.
df <- as.data.frame(colData(dds)[, "treatment"])
rownames(df) <- rownames(colData(dds))
colnames(df) <- "treatment"
pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
         cluster_cols=FALSE, annotation_col=df)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  

#plot dispersions.  gene-wise dispersions are in black, fitted values in red
plotDispEsts(dds)   ##this function is in DESEq2 package
#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))
#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="ros1 vs wt", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value
library('DESeq2')
#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")

##### Then, go for Lanver et al. 2018 #####
setwd("../Umaydis/Lanver2018")

data<-read.table("./RawReadCount/Lanver2018RawReadCount.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #6677 x 6, 6677 genes in 6 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("12hpi_rep1", "12hpi_rep2", "12hpi_rep3", "6dpi_rep1", "6dpi_rep2", "6dpi_rep3"),
                      treatment=as.factor(c(rep("12hpi",3), rep("6dpi",3))), replicate=as.factor(rep(1:3, 2)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## size factor varies between 0.62 - 1.66, slightly better when using pooled data
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Lanver2018_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
min(counts(data[,1]))
max(counts(data[,1]))
##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))  ##Rocketship plot seems not nice, probably because there are a lot of zero counts.
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 2:3] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,4)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,6)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))
#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
#If I want log2(6dpi/12hpi) --> needs to do results(dds, contrast=c("group", "6dpi", "12hpi"))
res <- results(dds, contrast=c("group", "6dpi", "12hpi"))
write.csv(res,file="Lanver2018_DESeq2ResultsStats.txt")
#order results table by the smallest adjusted p value
resOrdered <- res[order(res$padj),]
#summarize results
summary(res)  ##Only 19.1% is differentially expressed, 9.7% of genes have low counts!
write.csv(as.data.frame(resOrdered),
          file="Lanver2018_DESeq2Results_sorted.csv")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
par( mfrow = c(1, 2))
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )

#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Make the heatmap for two factors like Nadia's script. But this case I have only one factor
#df <- as.data.frame(colData(dds)[,c("treatment","replicate")])
#pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
#         cluster_cols=FALSE, annotation_col=df)
##Try making heatmap for only one factor, but the script may not be so neat.
df <- as.data.frame(colData(dds)[, "treatment"])
rownames(df) <- rownames(colData(dds))
colnames(df) <- "treatment"
pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
         cluster_cols=FALSE, annotation_col=df)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  

par(mfrow=c(1,1))
#plot dispersions.  gene-wise dispersions are in black, fitted values in red
plotDispEsts(dds)   ##this function is in DESEq2 package
#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))
#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="6dpi vs 12hpi", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-1,1),col="dodgerblue",lwd=2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value
library('DESeq2')
#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")

#####Perform read count normalization #####
##Paul et al. 2018 and Donaldson et al. 2017 RNASeq do not have replication
##So just transform read counts and do a rocketship plot.
library('DESeq2')  ##Load DESeq2_1.20.0
library('DESeq')   ##Load DESeq_1.32.0
library(RColorBrewer)
library("pheatmap")  ##Load pheatmap_1.0.12
library("ggplot2")    ##Load ggplot2_3.1.0
setwd("../Umaydis/Paul2018")
data<-read.table("./RawReadCount/Paul2018RawReadCount.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #6729 x 4, 6729 genes in 4 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("wt_HighN", "wt_LowN", "OverUmp2_HighN", "OverUmp2_LowN"),
                      treatment=as.factor(c("wt_HighN", "wt_LowN", "OverUmp2_HighN", "OverUmp2_LowN")), replicate=as.factor(rep(1, 4)))
#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## normalization coefficient ca. 0.87 - 1.11
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Paul2018_NormalizedReadCount.txt")

##Perform rocketship plots
##Start from log2
plot( 1+counts(dds, normalized=TRUE)[, 1:2], col="#00000020", pch=20, cex=0.3, log="xy" )
##Plot y = x line
x <- 1:100000
y <- 1:100000
lines(x, y, col="red")
##What about plot a line showing genes log2FC > 0.5
y.up <- x*(2^0.5)
lines(x, y, col="red")
y.down <- x*(2^-0.5)
lines(x, y, col="red")
plot( 1+counts(dds, normalized=TRUE)[, c(1,3)], col="#00000020", pch=20, cex=0.3, log="xy" )
lines(x, y, col="red")
#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  
#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")

##Go for Donaldson et al. 2017 study ##
data<-read.table("./RawReadCount/Donaldson2017RawReadCount.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #6692 x 3, 6692 genes in 3 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("Haploid521", "Haploid518", "Dikaryon"),
                      treatment=as.factor(c("Haploid521", "Haploid518", "Dikaryon")), replicate=as.factor(rep(1, 3)))
#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## normalization coefficient ca. 0.87 - 1.11
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Donaldson2017_NormalizedReadCount.txt")

##Perform rocketship plots
##Start from plot between Haploid 521 and 518
plot( 1+counts(dds, normalized=TRUE)[, 1:2], col="#00000020", pch=20, cex=0.3, log="xy",xlim=c(1,100000), ylim=c(1,100000) )
##Plot y = x line
x <- 1:100000
y <- 1:100000
##What about plot a line showing genes log2FC > 0.5
y.up <- x*(2^0.5)
lines(x, y.up, col="red")
y.down <- x*(2^-0.5)
lines(x, y.down, col="red")
##Expression level looks not super different, try plotting Haploid and Dikaryon
plot( 1+counts(dds, normalized=TRUE)[, c(1,3)], col="#00000020", pch=20, cex=0.3, log="xy",xlim=c(1,100000), ylim=c(1,100000) )
lines(x, y.up, col="red")
lines(x, y.down, col="red")
plot( 1+counts(dds, normalized=TRUE)[, c(2,3)], col="#00000020", pch=20, cex=0.3, log="xy",xlim=c(1,100000), ylim=c(1,100000) )
lines(x, y.up, col="red")
lines(x, y.down, col="red")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  
#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")


#############################################################################################
##### Go for Canalb dataset #####
###There is a problem on a dataset, will get back later ###
setwd("../Azadmanesh2017_Candida/")

###Seems like there are lots of variation for each rep of 37 C treatment
###Choose the one having least variation: what about between YPD30 and RPMI37
data<-read.table("./RawReadCount/Canalb_RawReadCount_Final.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #5992 x 6, 5992 genes in 6 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("YPD30_rep1", "YPD30_rep2", "YPD30_rep3", "RPMI37_rep1", "RPMI37_rep2", "RPMI37_rep3"),
                      treatment=as.factor(c(rep("YPD30",3), rep("RPMI37",3))), replicate=as.factor(rep(1:3, 2)))

##For the version of Jan 31, include all treatments
# samples <- data.frame(row.names=c("YPD30_rep1", "YPD30_rep2", "YPD30_rep3", "YPD30_rep3_2", "FBS37_rep1",
#                                   "FBS37_rep2", "FBS37_rep3", "FBS37_rep3_2", "Spider37_rep1", "Spider37_rep2",
#                                   "Spider37_rep3" , "Spider37_rep3_2", "Lee37_rep1", "Lee37_rep2", "Lee37_rep3",
#                                   "RPMI37_rep1", "RPMI37_rep2", "RPMI37_rep3"), treatment=as.factor(c(rep("YPD30",4),
#                                   rep("FBS37",4), rep("Spider37",4), rep("Lee37", 3), rep("RPMI37", 3))),
#                                   replicate=as.factor(c(rep(1:4, 3), rep(1:3, 2))))
##For solid media types, 5 treatments, 3 reps each
 samples <- data.frame(row.names=c("YPD30_rep1", "YPD30_rep2", "YPD30_rep3", "FBS37_rep1", "FBS37_rep2", "FBS37_rep3", "Spider37_rep1", "Spider37_rep2",
                                   "Spider37_rep3" , "Lee37_rep1", "Lee37_rep2", "Lee37_rep3", "RPMI37_rep1", "RPMI37_rep2", "RPMI37_rep3"), 
                                    treatment=as.factor(c(rep("YPD30",3), rep("FBS37",3), rep("Spider37",3), rep("Lee37", 3), rep("RPMI37", 3))),
                                   replicate=as.factor(rep(1:3, 5)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## size factor varies between 0.71 - 1.36, not much difference
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Canalb_Solid_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
min(counts(data[,1]))
max(counts(data[,1]))
##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))  ##Rocketship plot seems not nice, probably because there are a lot of zero counts.
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 2:3] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,4)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,6)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))
#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
#Analyzing a contrast between RPMI37 and YPD30
res <- results(dds, contrast=c("group", "FBS37", "YPD30"))
write.csv(res,file="Canalb_FBS37vsYPD30_DESeq2ResultsStats.txt")
#order results table by the smallest adjusted p value
resOrdered <- res[order(res$padj),]
#summarize results
summary(res)  ## 44% are differentially expressed
write.csv(as.data.frame(resOrdered),
          file="Canalb_FBS37vsYPD30_DESeq2Results_sorted.csv")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
par( mfrow = c(1, 2))
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )
par( mfrow = c(1, 1))
#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Try making heatmap for only one factor, but the script may not be so neat.
df <- as.data.frame(colData(dds)[, "treatment"])
rownames(df) <- rownames(colData(dds))
colnames(df) <- "treatment"
pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
         cluster_cols=FALSE, annotation_col=df)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)

par(mfrow=c(1,1))
#plot dispersions.  gene-wise dispersions are in black, fitted values in red
plotDispEsts(dds)   ##this function is in DESEq2 package
#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))
#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="37FBS vs 30YPD", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-0.5,0.5),col="dodgerblue",lwd=2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value
library('DESeq2')
#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")
#############################################################################################
##### Go for Ophnu dataset #####
setwd("../Nigg2016Ophiostoma/")

data<-read.table("./RawReadCount/Ophnu_RawReadCount.txt",header=TRUE)
##create a count matrix of just gene counts, with genes as rownames
rownames(data) <- data[,1]
countMatrix<-data[-((nrow(data)-4):nrow(data)),-1]
#remove zero count genes, save memory and make calculations go faster
countsNozero=countMatrix[rowSums(countMatrix)!=0,]
dim(countsNozero)   #8393 x 6, 8393 genes in 6 samples 
#set a matrix showing an experimental design, make sure to use consistant library name
#when order the treatments --> start from treatment having yeast followed by hyphae
samples <- data.frame(row.names=c("Ophnu_0h_rep1", "Ophnu_0h_rep2", "Ophnu_0h_rep3", "Ophnu_27h_rep1", 
                                  "Ophnu_27h_rep2", "Ophnu_27h_rep3"),
                      treatment=as.factor(c(rep("0h",3), rep("27h",3))), replicate=as.factor(rep(1:3, 2)))

#input count matrix into DESeq2
data<-newCountDataSet(countsNozero,samples)  # newCountDataset is a function from DESeq package (not DESEq2)
#provide sample information (columns of the count matrix) as a dataframe. In this case, one factor, only treatment and replicates
colData<-pData(data)[,c("treatment", "replicate")]
head(colData)
countData<-counts(data)
head(countData)
##This design is normal, no interaction effect. Test only single factor, two treatments.
dds<- DESeqDataSetFromMatrix(countData = countData,
                             colData = colData,
                             design =~ treatment)
dds <- DESeq(dds)
#see what the size factors for library size correction are
sizeFactors(dds)   ## size factor varies between 0.54 - 1.33, not much difference
#see what tests have been done, and what they are called
resultsNames(dds)
#combine factors of interest into a single factor with all combinations of the original factors
#change the design to include just the group factor
dds$group<-factor(paste0(dds$treatment))
dds$group
design(dds)<-~group
dds<-DESeq(dds)
resultsNames(dds)
write.csv(counts(dds, normalized=TRUE),file="Ophnu_NormalizedReadCount.txt")

##Explore the distribution of the read counts for each gene
min(counts(data[,1]))
max(counts(data[,1]))
##For DESEq2, there is no need to trim lowly expressed genes off as they have done internal independent
##filtering for us.
##Perform a rocketship plot to make sure gene expression between reps in the same treatment are correlated
par(mfrow=c(3,3))  ##Rocketship plot seems not nice, probably because there are a lot of zero counts.
##Start from log2
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, 2:3] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,3)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(5,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(4,6)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(1,4)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(2,5)] ), col="#00000020", pch=20, cex=0.3 )
plot( log2( 1+counts(dds, normalized=TRUE)[, c(3,6)] ), col="#00000020", pch=20, cex=0.3 )
par(mfrow=c(1,1))
#generate a results table; if no arguments are given to results, the results will be for the 
#last variable in the design formula and, if this is a factor, the comparison will be the last level of
#this variable over the first level.  treated versus untreated means that the estimates are of the
#log2(treated/untreated)
res <- results(dds, contrast=c("group", "hypha", "yeast"))
write.csv(res,file="Ophnu_27hvs0h_DESeq2ResultsStats.txt")
summary(res)  ##65% differentially expressed, only 2% have low counts
resOrdered <- res[order(res$padj),]
write.csv(as.data.frame(resOrdered),
          file="Ophnu_27hvs0h_DESeq2Results_sorted.csv")

#rld is preferable if size factors vary a lot, and some of them do. so will use this
#rlog is good for exploring multivariate dataset
rld <- rlog(dds)
par( mfrow = c(1, 2))
plot( log2( 1+counts(dds, normalized=TRUE)[, 1:2] ), col="#00000020", pch=20, cex=0.3 )
plot( assay(rld)[, 1:2], col="#00000020", pch=20, cex=0.3 )

#generate a heatmap from the 90 most highly expressed genes (on the data 
#after a regularized log transformation was performed)
select <- order(rowMeans(counts(dds,normalized=TRUE)),decreasing=TRUE)[1:90]  ##Sort and select most highly expressed genes
nt <- normTransform(dds)   ##normalized transformation
log2.norm.counts <- assay(nt)[select,]
##Try making heatmap for only one factor, but the script may not be so neat.
df <- as.data.frame(colData(dds)[, "treatment"])
rownames(df) <- rownames(colData(dds))
colnames(df) <- "treatment"
pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=TRUE,
         cluster_cols=FALSE, annotation_col=df, cex=0.7)

#generate a heatmap of sample-to-sample distances
sampleDists <- dist(t(assay(rld)))
sampleDistMatrix <- as.matrix(sampleDists)
rownames(sampleDistMatrix) <- paste(rld$treatment, rld$replicate, sep="-")
colnames(sampleDistMatrix) <- NULL
colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
pheatmap(sampleDistMatrix,
         clustering_distance_rows=sampleDists,
         clustering_distance_cols=sampleDists,
         col=colors)
##Some functions down the road are on DESeq2, so may need to unload DESeq. This includes plotDipspEsts(), plotPCA().
detach("package:DESeq", unload=TRUE)  

par(mfrow=c(1,1))
#plot dispersions.  gene-wise dispersions are in black, fitted values in red
plotDispEsts(dds)   ##this function is in DESEq2 package
#make a PCA plot
plotPCA(rld, intgroup="treatment")   ##this function is in DESEq2 package
datapca <- plotPCA(rld, intgroup="treatment", returnData=TRUE)
percentVar <- round(100 * attr(datapca, "percentVar"))
ggplot(datapca, aes(PC1, PC2, color=treatment)) +
  geom_point(size=6) +geom_text(aes(label=rownames(datapca)), size=3,hjust=0.5,vjust=1,colour = "black")+
  xlab(paste0("PC1: ",percentVar[1],"% variance")) +
  ylab(paste0("PC2: ",percentVar[2],"% variance"))
#only significant results
resSig <- subset(resOrdered, padj < 0.01)

##make an MA plot for comparison
##Call a function from a specific package DESeq2, in case the function is masked by other packages
yl <- c(-6,6)
DESeq2::plotMA(res, main="hypha vs yeast", ylim=yl, xlab='Mean Expression', ylab='logFC')
abline(h=c(-0.5,0.5),col="dodgerblue",lwd=2)
par(mfrow=c(1,1),mar=c(5,4,4,2)+0.1)  ##Default value
library('DESeq2')
#what filter threshold was used in performing the independent filtering?
metadata(res)$filterThreshold

#look at cooks distance plots to see if one of the samples has consistenly more outliers
#than the others
par(mar=c(8,5,2,2))
boxplot(log10(assays(dds)[["cooks"]]), range=0, las=2, ylab="Cook's Distance Values")
