## Umaydis_MicroarrayAnalysis_Apr2019
## Teeratas Kijpornyongpan
## 2 Apr 2019
## This script is from BTNY590 Pete's class to analyze Umaydis microarray data.
## Two GEO datasets: GSE53947 from Lanver 2014 --> filamentous growth under hydrophobicity
##                   GSE28916 from Horst 2012 --> yeast growth under nit2 mutant

#####Start by loading required packages from Bioconductor #####
source("http://bioconductor.org/biocLite.R")

#Install all required packages
#BiocInstaller::biocLite("GEOquery")   
#BiocInstaller::biocLite("affy")
#BiocInstaller::biocLite("limma")

##Check version of package by sessionInfo() ot packageVersion("[Package name]")
library(affy) ##Load affy_1.58.0
library(limma) ##Load limma_3.36.5
library(RColorBrewer)

#####Start by working on GSE53947: Lanver 2014 U maydis microarray data #####
### code chunk number 1: GEO_PROCESSED, Download GEO dataset
###################################################
library(GEOquery)     ##Load GEOquery_2.48.0
my.gse <- "GSE53947"
setwd("../Umaydis/Microarray")
##get published data and metadata
##this step is slow because of download and reformatting
##create directory for files downloaded from GEO
if(!file.exists("geo_downloads")) dir.create("geo_downloads")
if(!file.exists("results/QC"))  dir.create("results/QC", recursive=T)
##get data from GEO
##This one is to download the file
#my.geo.gse <- getGEO( GEO = my.gse, destdir ="./geo_downloads/", GSElimits=NULL, GSEMatrix=T, AnnotGPL=F, getGPL=F)
my.geo.gse <- getGEO( filename ="./geo_downloads/GSE53947_series_matrix_modified.txt", GSElimits=NULL, GSEMatrix=T, AnnotGPL=F, getGPL=F)
##For some reasons I have a difficulty subsetting unwanted probesets from my.geo.gse --> so I did this manually (remove control probes
##with AFFX and probes with cross hybridization _x_) and reload the modified geo.gse file

##My data structure isn't a list because using diffirent getGEO arguments
##due to iTaP system, but change later when turning this in
#my.geo.gse <- my.geo.gse[[1]]
##object is now an ExpressionSet
#class(my.geo.gse)
##explore structure of data
class(my.geo.gse)
length(my.geo.gse)
names(my.geo.gse)
str(my.geo.gse)

colnames(pData(my.geo.gse))
pData(my.geo.gse)$data_processing[1]
head(exprs(my.geo.gse))
summary(exprs(my.geo.gse))
dim(my.geo.gse)
### code chunk number 2: Get supplementary files GEO_CEL
###################################################
## Same thing with getGEO when working on iTAP computer.
## I have to download them directly, will change
## later when turning in the assignment
getGEOSuppFiles(my.gse, makeDirectory=T, baseDir="geo_downloads")
list.files("geo_downloads")
list.files("geo_downloads/GSE53947")
##readLines("geo_downloads/GSE53947/filelist.txt")
##The function creates a directory and downloads the "tarball" that contains
##gzipped CEL files. We need to untar the tarball but we do not to unzip
##the CEL files. R can read them in compressed format.
untar("geo_downloads/GSE53947/GSE53947_RAW.tar", exdir="geo_downloads/GSE53947/CEL")
my.cels <- list.files("geo_downloads/GSE53947/CEL")
my.cels

##### Abandoned part for processing microarray data #####
## Actually my.geo.gse is an already normalized data ready to be analyze, so we may not need Affy
## package to process the microarray data
### code chunk number 3: PHENODATA_FILE --> write a summary table for microarray experiment
##make data frame of phenoData
my.pdata <- as.data.frame(pData(my.geo.gse), stringsAsFactors=F)
dim(my.pdata)
colnames(my.pdata)
my.pdata[, c("title", "geo_accession", "description")]
my.pdata <- my.pdata[, c("title", "geo_accession", "description")]
my.pdata
##the rownames of the data frame must be the same as the CEL file names.
##For this data, we need to do a bit of tinkering.
rownames(my.pdata) == my.cels
##Remove first element, and rename all CEL data --> maybe not neccessary....
my.cels <- my.cels[-1]
rownames(my.pdata)
temp.rownames <- paste(rownames(my.pdata), ".CEL.gz", sep="")
temp.rownames == my.cels ##Still FALSE in two positions
rownames(my.pdata) <- temp.rownames
write.table(my.pdata, file="geo_downloads/GSE53947/CEL/GSE53947_SelectPhenoData.txt", sep="\t", quote=F)

### code chunk number 4: READ_AFFY
##Perform affy normalization
library(affy)
cel.path <- "geo_downloads/GSE53947/CEL"
my.affy <- ReadAffy(celfile.path=cel.path, phenoData=paste(cel.path, "GSE53947_SelectPhenoData.txt", sep="/"))
my.affy
pData(my.affy)
head(exprs(my.affy))
dim(exprs(my.affy))
pData(my.affy)$title
pData(my.affy)$description
table(pData(my.affy)$description)
##create shorter descriptive levels and labels
pData(my.affy)$sample.levels <- rep(c("T0", "T30", "T60"), 2)
pData(my.affy)$sample.labels <- paste(pData(my.affy)$sample.levels, c(1, 1, 1, 2, 2, 2), sep=".")
pData(my.affy)
table(pData(my.affy)$description, pData(my.affy)$sample.levels)
table(pData(my.affy)$title, pData(my.affy)$sample.labels)

### code chunk number 5: RMA_NORM
##Calculate gene level expression measures
my.rma <- rma(my.affy, normalize=FALSE, background=FALSE)
head(exprs(my.rma))
dim(exprs(my.affy))
dim(exprs(my.rma))
pData(my.rma)
##make sample.levels a factor making C.06 the reference.
pData(my.rma)$sample.levels <- as.factor(pData(my.rma)$sample.levels)
pData(my.rma)$sample.levels <- relevel(pData(my.rma)$sample.levels, ref="T0")
levels(pData(my.rma)$sample.levels)
plotDensity(exprs(my.rma))
##Load limma to get plotDensities function. Load RColorBrewer to provide good
##color palettes.
library(limma)
library(RColorBrewer)
##show palettes available with RColorBrewer
level.pal <- brewer.pal(3, "Dark2")
##sample.levels is a factor. unname will change this to integer data
##to easily assign colors to the various levels.
level.cols <- level.pal[unname(pData(my.rma)$sample.levels)]
##Density plot of rma values show need for normalization
plotDensities(exprs(my.rma), legend=F, col=level.cols, main="Arrays Not Normalized")
legend("topright", legend=levels(pData(my.rma)$sample.levels), fill=level.pal)
pdf(file="results/QC/DensityNoNorm.pdf", w=6, h=6)
plotDensities(exprs(my.rma), legend=F, col=level.cols, main="Arrays Not Normalized")
legend("topright", legend=levels(pData(my.rma)$sample.levels), fill=level.pal)
dev.off()
##Boxplot is another way of showing the same thing.
boxplot(exprs(my.rma), las=2, names=pData(my.rma)$sample.labels, outline=F, col=level.cols, main="Arrays Not Normalized")
pdf(file="results/QC/DensityNoNorm.pdf", w=6, h=6)
boxplot(exprs(my.rma), las=2, names=pData(my.rma)$sample.labels, outline=F, col=level.cols, main="Arrays Not Normalized")
dev.off()
##Now use normalization and background correction
my.rma <- rma(my.affy, normalize=TRUE, background=TRUE)
plotDensities(exprs(my.rma), legend=F, col=level.cols, main="Arrays Normalized")
pdf(file="results/QC/DensityNorm.pdf", w=6, h=6)
plotDensities(exprs(my.rma), legend=F, col=level.cols, main="Arrays Normalized")
dev.off()
boxplot(exprs(my.rma), las=2, names=pData(my.rma)$sample.labels, outline=F, col=level.cols, main="Arrays Normalized")
pdf(file="results/QC/DensityNorm.pdf", w=6, h=6)
boxplot(exprs(my.rma), las=2, names=pData(my.rma)$sample.labels, outline=F, col=level.cols, main="Arrays Normalized")
dev.off()

### code chunk number 6: PA_CALLS
my.calls <- mas5calls(my.affy)
head(exprs(my.calls))
table(exprs(my.calls)[, 1])
##the next expression will work down the rows of the data matrix and 
##return the number of samples in which the gene has been called as present.
present <- apply(exprs(my.calls), 1, function(x)(sum(x == "P")))
head(present)
table(present)
prop.table(table(present)) * 100

### code chunk number 7: COMPARE_DENSITIES
table(present >= 2)
##We are going to discard more than half of the genes on the array.
plotDensities(exprs(my.geo.gse)[present >= 2, ], col=level.cols, legend=F, main="Present >= 2")
plotDensities(exprs(my.geo.gse)[present < 2, ], col=level.cols, legend=F, main="Present < 2")
#######################################################

##### Inspect how the data look like #####
##create shorter descriptive levels and labels
pData(my.geo.gse)$sample.levels <- c(rep("WT_control", 3), rep("WT_wax", 3), rep("WT_waxFA", 3), rep("mutant_wax", 3), rep("mutant_waxFA", 3))
pData(my.geo.gse)$sample.labels <- paste(pData(my.geo.gse)$sample.levels, rep(1:3, 3), sep=".")
##make sample.levels a factor making C.06 the reference.
pData(my.geo.gse)$sample.levels <- as.factor(pData(my.geo.gse)$sample.levels)
pData(my.geo.gse)$sample.levels <- relevel(pData(my.geo.gse)$sample.levels, ref="WT_control")
levels(pData(my.geo.gse)$sample.levels)
pData(my.geo.gse)
table(pData(my.geo.gse)$description, pData(my.geo.gse)$sample.levels)
table(pData(my.geo.gse)$title, pData(my.geo.gse)$sample.labels)
library(RColorBrewer)
##show palettes available with RColorBrewer
level.pal <- brewer.pal(5, "Dark2")
##sample.levels is a factor. unname will change this to integer data
##to easily assign colors to the various levels.
level.cols <- level.pal[unname(pData(my.geo.gse)$sample.levels)]
##Density plot of rma values show need for normalization
plotDensities(exprs(my.geo.gse), legend=F, col=level.cols, main="Arrays Normalized from GSE")
legend("topright", legend=levels(pData(my.geo.gse)$sample.levels), fill=level.pal)
pdf(file="results/QC/DensityNormFromGSE.pdf", w=6, h=6)
plotDensities(exprs(my.geo.gse), legend=F, col=level.cols, main="Arrays Normalized from GSE")
legend("topright", legend=levels(pData(my.geo.gse)$sample.levels), fill=level.pal)
dev.off()
pdf(file="results/QC/BoxplotNormFromGSE.pdf", w=6, h=6)
boxplot(exprs(my.geo.gse), las=2, names=pData(my.geo.gse)$sample.labels, outline=F, col=level.cols, main="Arrays Normalized from GSE")
dev.off()
##Check if there are any rows/probes having no expression
nrow(exprs(my.geo.gse))  ##6540 probes
table(rowSums(exprs(my.geo.gse) > 2)) ##See how many samples in each probe have expression value > 2
nrow(exprs(my.geo.gse)[rowSums(exprs(my.geo.gse) > 2) >= 2,])  ##6795 probes having expression value > 2 for at least 2 samples

dim(exprs(my.geo.gse))
##This part not neccessary, as I have removed this from the original gse file
# ##remove probesets that can crosshybridize with other genes
# exprs(my.geo.gse) <- exprs(my.geo.gse)[-grep("_x_", rownames(exprs(my.geo.gse))), ]
# dim(my.geo.gse)
# ##remove probesets that are Affymetrix controls
# exprs(my.geo.gse) <- exprs(my.geo.gse)[-grep("AFFX", rownames(exprs(my.geo.gse))), ]
# dim(my.geo.gse)

##### Visualize variability across different treatments #####
## Through MDS plot
plotMDS(exprs(my.geo.gse), labels=pData(my.geo.gse)$sample.labels, top=500, gene.selection="common", main="MDS Plot to Compare Replicates", cex=0.7)
pdf(file="results/QC/MDS_plot.pdf", w=6, h=6)
plotMDS(exprs(my.geo.gse), labels=pData(my.geo.gse)$sample.labels, top=500, gene.selection="common", main="MDS Plot to Compare Replicates", cex=0.7)
dev.off()
## Through hierarchical clustering
## make z-score matrix
cluster.dat <- exprs(my.geo.gse)
gene.mean <- apply(cluster.dat, 1, mean)   ##use mean function for each row (value "1") of cluster.dat
gene.sd <- apply(cluster.dat, 1, sd)
cluster.dat <- sweep(cluster.dat, 1, gene.mean, "-") ##For each row i (1 refers to row), each cell is subtracted by gene.mean[i]
cluster.dat <- sweep(cluster.dat, 1, gene.sd, "/")   ##For each row i (1 refers to row), each cell is divided by gene.sd[i]
## calculate Euclidean distance and perform
## hierarchical clustering.
my.dist <- dist(t(cluster.dat), method="euclidean")
my.hclust <- hclust(my.dist, method="average")
my.hclust$labels <- pData(my.geo.gse)$sample.labels
plot(my.hclust, cex=0.75, main="Comparison of Biological Replicates with Euclidean Distance")
pdf(file="results/QC/Hclust_Euclid_plot.pdf", w=6, h=6)
plot(my.hclust, cex=0.75, main="Comparison of Biological Replicates with Euclidean Distance")
dev.off()
## calculate Pearson distance and perform
## hierarchical clustering.
my.cor <- cor(cluster.dat)
print(my.cor)
my.dist <- as.dist(1 - my.cor)
my.hclust <- hclust(my.dist, method="average")
my.hclust$labels <- pData(my.geo.gse)$sample.labels
plot(my.hclust, cex=0.75, main="Comparison of Biological Replicates with Pearson Distance")
pdf(file="results/QC/Hclust_Pearson_plot.pdf", w=6, h=6)
plot(my.hclust, cex=0.75, main="Comparison of Biological Replicates with Pearson Distance")
dev.off()

##### Design matrix and perform Limma stat to find DGE #####
### code chunk: DESIGN_MATRIX
my.trts <- unique(pData(my.geo.gse)$sample.levels)
my.trts
##elegant way to make the matrix
my.design <- sapply(my.trts, function(x)(as.integer(pData(my.geo.gse)$sample.levels==x)))
rownames(my.design) <- pData(my.geo.gse)$sample.labels
colnames(my.design) <- my.trts
my.design
##manual and easy to understand way to make the design matrix
my.design2 <- matrix(0, nrow=ncol(my.geo.gse), ncol=length(my.trts))
colnames(my.design2) <- my.trts
rownames(my.design2) <- pData(my.geo.gse)$sample.labels
pData(my.geo.gse)$sample.levels
head(my.design2)
my.design2[1:3, 1] <- 1
my.design2[4:6, 2] <- 1
my.design2[7:9, 3] <- 1
my.design2[10:12, 4] <- 1
my.design2[13:15, 5] <- 1
my.design
my.design2
summary(my.design == my.design2)
all.equal(my.design, my.design2)
rm(my.design2)

### code chunk: LIMMA_STATS
##determine the average effect (coefficient) for each treatment
my.fit <- lmFit(my.geo.gse, my.design)
my.fit
##specify the contrast of interest using the levels from the design matrix
my.contrasts <- makeContrasts(WaxvControl = WT_wax - WT_control, WaxFAvControl = WT_waxFA - WT_control, levels = my.design)
##determine coefficients and standard errors for contrasts
contrast.fit <- lapply(1:2, function(x)(contrasts.fit(my.fit, contrasts=my.contrasts[, x])))
names(contrast.fit) <- colnames(my.contrasts)
##perform the statistical tests for the contrasts
contrast.eb <- lapply(contrast.fit, function(x)(eBayes(x, proportion=0.1, trend=FALSE, robust=FALSE)))
##summarize the results. I always include all probesets and never sort
contrast.tt <- lapply(contrast.eb, function(x)(topTable(x, adjust="BH", number=length(x$coefficients), sort.by="none")))
##produce a vector of 1, 0, and -1 corresponding to up, unchanged or
##downregulated genes at the specified cutoffs
contrast.tests <- lapply(contrast.eb, function(x)(decideTests(x, method="separate", adjust.method="BH", p.value=0.05, lfc=0)))
contrast.tests <- do.call(cbind, contrast.tests)
colnames(contrast.tests) <- colnames(my.contrasts)
for(i in 1:length(contrast.tt)){
    contrast.tt[[i]]$Result <- contrast.tests[, i]
}
dge.genes <- apply(contrast.tests, 1, function(x)(any(x != 0)))
table(dge.genes)
ma.cols <- brewer.pal(11, "RdBu")[c(2, 10)]
##Produce plots of results
plotMA(contrast.eb[["WaxvControl"]], status=contrast.tests[, "WaxvControl"], hl.pch=20, hl.col=ma.cols, main="Wax vs Control")
pdf(file="results/MA_plot_WaxvControl.pdf", w=8, h=6)
plotMA(contrast.eb[["WaxvControl"]], status=contrast.tests[, "WaxvControl"], hl.pch=20, hl.col=ma.cols, main="Wax vs Control")
dev.off()
plotMA(contrast.eb[["WaxFAvControl"]], status=contrast.tests[, "WaxFAvControl"], hl.pch=20, hl.col=ma.cols, main="WaxFA vs Control")
pdf(file="results/MA_plot_WaxFAvControl.pdf", w=8, h=6)
plotMA(contrast.eb[["WaxFAvControl"]], status=contrast.tests[, "WaxFAvControl"], hl.pch=20, hl.col=ma.cols, main="WaxFA vs Control")
dev.off()

##revisit the multi-dimensional scaling plots for the DEGs only
plotMDS(exprs(my.geo.gse)[dge.genes, ], labels=pData(my.geo.gse)$sample.labels, top=1000, main=paste(my.gse, "MDS Plot to Compare DEG"), cex=0.8, cex.main=0.9)
##produce version that drops the labels and adds different points, colors and legends
plotMDS(exprs(my.geo.gse)[dge.genes, ], ylim=c(-0.9,1),pch=c(rep(16:18,5)), col=level.cols, labels=NULL, top=1000, main=paste(my.gse, "MDS Plot to Compare DEG"), cex=1.5, cex.main=0.9)
legend1 <- c("array1", "array2", "array3")
legend2 <- as.character(my.trts)
legend("top", horiz=T, bty="n", legend=legend1, pch=c(16, 17), cex=0.8)
legend("bottom", horiz=T, bty="n", legend=legend2, fill=level.pal, cex=0.8)
pdf(file="results/MDS_plot_DGE_genes.pdf", w=6, h=6)
plotMDS(exprs(my.geo.gse)[dge.genes, ], ylim=c(-0.8,1), pch=c(rep(16:18,5)), col=level.cols, labels=NULL, top=1000, main=paste(my.gse, "MDS Plot to Compare  Differentially-Expressed Genes"), cex=1.5, cex.main=0.9)
legend1 <- c("array1", "array2", "array3")
legend2 <- as.character(my.trts)
legend("top", horiz=T, bty="n", legend=legend1, pch=c(16, 17), cex=0.8)
legend("bottom", horiz=T, bty="n", legend=legend2, fill=level.pal, cex=0.5)
dev.off()

##### Write out the summary table #####
for(i in 1:length(contrast.tt)){
    write.table(contrast.tt[[i]], file=paste(my.gse, names(contrast.tt)[i], "TopTable.txt", sep="_"), sep="\t", quote=FALSE, row.names=TRUE)
}

##### Finally, find a way to convert probeID to Ustma2.2_proteinID#####
setwd("../Umaydis/Microarray")
probe.umID <- read.table(file="GPL3681_ProbeID.txt", header=TRUE, sep="\t", stringsAsFactors=FALSE)
um.version <- read.table(file="UmaydisVersion.txt", header=TRUE, sep="\t", stringsAsFactors=FALSE)
head(probe.umID)
##Add another column for probe.umID as Ustma2.2_proteinID
probe.umID$Ustma2.2_proteinID <- 0
head(probe.umID)
table(um.version$Ustma2.2_umID == um.version$Ustma2.1_umID) ##three elements are FALSE
which((um.version$Ustma2.2_umID == um.version$Ustma2.1_umID) ==FALSE)
um.version[c(733,1639,2137),] ##Row 733 has um01695 annotated in probeID, row1639 not present, row 2137 has um10807 annotated in probeID
um.version[733,2] <- "um01695"
um.version[c(733,1639,2137),]
## Then, make a loop to assign Ustma2.2_proteinID
for ( i in 1:nrow(probe.umID) ) {
  if ( length(unique(um.version$Ustma2.2_umID == probe.umID$ORF_INFO[i])) == 2 ) {
    probe.umID$Ustma2.2_proteinID[i] <-  um.version[which(um.version$Ustma2.2_umID == probe.umID$ORF_INFO[i]),]$Ustma2.2_protID
  }
}
length(which(probe.umID$Ustma2.2_proteinID == 0))
##There are a lot of mixing between um ID between version 1 and 2 --> try looping again to catch um ID version 1
##with JGI protein model from version2
for ( i in 1:nrow(probe.umID) ) {
  if ( (length(unique(um.version$Ustma1_umID == probe.umID$ORF_INFO[i])) == 2) & (probe.umID$Ustma2.2_proteinID[i] == 0) ) {
    probe.umID$Ustma2.2_proteinID[i] <-  um.version[which(um.version$Ustma1_umID == probe.umID$ORF_INFO[i]),]$Ustma2.2_protID
  }
}
length(which(probe.umID$Ustma2.2_proteinID == 0))
probe.umID$Ustma2.2_proteinID
head(probe.umID)
write.table(probe.umID, file="probeID_Ustma2_2ID.txt", sep="\t", quote=FALSE)

##Then, summon Microarray result table, and replace with Ustma2.2 proteinID
DEG.table <- read.table(file="results/GSE53947_WaxvControl_TopTable.txt", header=TRUE, sep="\t")
head(DEG.table)
##Adjust colnames to have the same annotation with the results from DESeq2
colnames(DEG.table) <- c("log2FoldChange", "baseMean", "t", "pvalue", "padj", "B", "Result")
##Then, use probe.umID to convert probe ID to Ustma2.2 protein ID
DEG.table$Ustma2.2_ProteinID <- 0

for ( i in 1:nrow(DEG.table) ) {
  if ( length(unique(probe.umID$ID == rownames(DEG.table)[i])) == 2 ) {
    ##Then, check if there is Ustma2.2_proteinID assigned. If the value is not 0, assign a new value
    if ( probe.umID[which(probe.umID$ID == rownames(DEG.table)[i])[1],]$Ustma2.2_proteinID != 0 ) {
      DEG.table$Ustma2.2_ProteinID[i] <- as.character(probe.umID[which(probe.umID$ID == rownames(DEG.table)[i])[1],]$Ustma2.2_proteinID)
    }
  }
}
DEG.table <- DEG.table[,c(8, 1:7)]
head(DEG.table)
nrow(DEG.table); length(unique(DEG.table$Ustma2.2_ProteinID))
DEG.table <- DEG.table[order(DEG.table$Ustma2.2_ProteinID),]
##Remove rows with unassigned Ustma2.2 proteinID
DEG.table <- DEG.table[DEG.table$Ustma2.2_ProteinID != 0,]
##Remove rows with duplicated probes
DEG.table <- DEG.table[!(duplicated(DEG.table$Ustma2.2_ProteinID)),]
head(DEG.table)
##Finally transform ProteinID into rownames
rownames(DEG.table) <- DEG.table$Ustma2.2_ProteinID
DEG.table <- DEG.table[,-1]
write.table(DEG.table, file="GSE53947_WaxvControl_TopTable_Ustma2_2ID.txt", sep="\t")

###################################################
### code chunk number 27: sessionInfo
###################################################
sessionInfo()
