## CompRNASeq_v2_Apr2019
## Teeratas Kijpornyongpan
## 4 Apr 2019
## This script is to perform comparative transcriptomics to find genes
## concordantly upregulated/downregulated in all species of interest
## as well as to make any visualization
## For version 2, find a better to improve the analyses:
## 1) Find a combined p-value method found in MetaRNA seq package for studies used by DESeq2 package
## 2) Ustma study (Lanver et al. 2014) uses microarray data --> compare and see, probably not suitable
##    for using combined p-value as it comes from a diffrent way of analysis

##Load metaRNASeq package
#install.packages("metaRNASeq")
#library("metaRNASeq")

##### First, import the data: Orthogroup table and DGE analyses table of each species #####
##Load orthogroup.table
orthogroup.table <- read.csv("../OrthoFinder_Jan2019/Single_copy_orthogroups_FiveSpecies_v1Jan2019.txt",
                             sep = "\t", header = TRUE)
rownames(orthogroup.table) <- orthogroup.table[,1]
orthogroup.table <- orthogroup.table[,-1]
orthogroup.table

##Load RNASeq results
Meimi.DEG <- read.csv("../Ust_Illumina/Results_v1/Meimi_DESeq2Results_sorted.csv", header=TRUE)
colnames(Meimi.DEG)[1] <- "gene.id"
##I think we need only gene.id, log2FoldChange and p-value, both raw and adjusted
Meimi.DEG <- Meimi.DEG[, c(1,3,6,7)]
head(Meimi.DEG)
dim(Meimi.DEG)   ## 7400 genes

Tilwa.DEG <- read.csv("../Ust_Illumina/Results_v1/Tilwa_DESeq2Results_sorted.csv", header=TRUE)
colnames(Tilwa.DEG)[1] <- "gene.id"
##I think we need only gene.id, log2FoldChange and p-value, both raw and adjusted
Tilwa.DEG <- Tilwa.DEG[, c(1,3,6,7)]
head(Tilwa.DEG)
dim(Tilwa.DEG)   ## 6999 genes

##Ustma has a different format
Ustma.DEG <- read.csv("../Umaydis/Microarray/Results_v1/GSE53947_WaxvControl_TopTable_Ustma2_2ID.txt", header=TRUE, sep = "\t")
head(Ustma.DEG)
Ustma.DEG$gene.id <- rownames(Ustma.DEG)
##I think we need only gene.id, log2FoldChange and p-value, and round up the number into 4 digits
Ustma.DEG <- Ustma.DEG[, c(8,1,4,5)]
rownames(Ustma.DEG) <- 1:nrow(Ustma.DEG)
head(Ustma.DEG)
dim(Ustma.DEG)   ## 5639 genes

Ophnu.DEG <- read.csv("../Nigg2016Ophiostoma/Results_v1/Ophnu_27hvs0h_DESeq2Results_sorted.csv", header=TRUE)
colnames(Ophnu.DEG)[1] <- "gene.id"
##I think we need only gene.id, log2FoldChange and p-value, and round up the number into 4 digits
Ophnu.DEG <- Ophnu.DEG[, c(1,3,6,7)]
dim(Ophnu.DEG)   ## 8393 genes

Ophnu.DEG2 <- read.csv("../Nigg2015Ophiostoma/Results_v1/Ophnu_hypha_vs_yeast_DESeq2Results_sorted.csv", header=TRUE)
colnames(Ophnu.DEG2)[1] <- "gene.id"
##I think we need only gene.id, log2FoldChange and p-value, and round up the number into 4 digits
Ophnu.DEG2 <- Ophnu.DEG2[, c(1,3,6,7)]
dim(Ophnu.DEG2)   ## 8610 genes

##### Then, write a script to find orthogroups concurrently upregulated/downregulated #####
##### Meimi and Tilwa #####
## For version 2, recruit orthogroups first
## Using a loop to go for each orthogroup
DEG.orthogroup <- data.frame()
orthogroup.interest <- orthogroup.table[orthogroup.table$Tilwa > 0 & orthogroup.table$Meimi > 0,c(2,4)]
for ( i in 1:nrow(orthogroup.interest) ) {
  Meimi.interest <- Meimi.DEG[which(Meimi.DEG$gene.id == orthogroup.interest$Meimi[i]),]
  Tilwa.interest <- Tilwa.DEG[which(Tilwa.DEG$gene.id == orthogroup.interest$Tilwa[i]),]
  DEG.orthogroup <- rbind(DEG.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest))
}
rownames(DEG.orthogroup) <- 1:nrow(DEG.orthogroup)
colnames(DEG.orthogroup) <- c("Meimi", "Meimi.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj",
                              "Tilwa", "Tilwa.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj")
head(DEG.orthogroup)
##After that, set a list storing raw p-value and logFC for each study
rawpval <- list("pval1"=DEG.orthogroup$Meimi.pvalue, "pval2"=DEG.orthogroup$Tilwa.pvalue)
FC <- list("FC1"=DEG.orthogroup$Meimi.log2FC, "FC2"=DEG.orthogroup$Tilwa.log2FC)
##Check histogram of p-value to make sure it has uniform distribution. This is required assumption for combined p-value
par(mfrow=c(1,2))
hist(rawpval[[1]], breaks=100, col="grey", main="Meimi p-value distribution", xlab="Raw p-values", ylim=c(0,250))
hist(rawpval[[2]], breaks=100, col="grey", main="Tilwa p-value distribution", xlab="Raw p-values", ylim=c(0,250))
##Perform p-value combiantion
##Fisher method
fishcomb <- fishercomb(rawpval, BHth=0.01)
str(fishcomb)
head(cbind(fishcomb[[4]], DEG.orthogroup$Meimi.padj, DEG.orthogroup$Tilwa.padj), n=20)
sum(fishcomb[[4]] < 0.01) ##more genes are significant DE, 2121 in total now!
invnormcomb <- invnorm(rawpval, nrep=c(3,4), BHth=0.01)
sum(invnormcomb[[4]] < 0.01)   ##2037 genes are DE!
##Seems like p-value combination may not be working in this case. Probably because when doing orthogroups assessment
##parts of the genes that are not orthologous were filtered out, and those genes probably represent the missing part
##of p-value distribution
##Probably something is misleading here.

##### Meimi, Tilwa and Ustma #####
  concord.DE.orthogroup <- data.frame()
  conflict.DE.orthogroup <- data.frame()
  semi.non.DE.orthogroup <- data.frame()
  non.DE.orthogroup <- data.frame()
  num.DE.Meimi <- 0; num.nonDE.Meimi <- 0; num.DE.Tilwa <- 0; num.nonDE.Tilwa <- 0
  num.DE.Ustma <- 0; num.nonDE.Ustma <- 0
  orthogroup.interest <- orthogroup.table[orthogroup.table$Tilwa > 0 & orthogroup.table$Meimi > 0 & orthogroup.table$Ustma > 0,c(2,4,5)]
for ( i in 1:nrow(orthogroup.interest) ) {
  ##We need logical variables for FC (+, - or 0)
  Meimi.FC <- vector()
  Tilwa.FC <- vector()
  Ustma.FC <- vector()

##Then, extract orthogroup of interest
  Meimi.interest <- Meimi.DEG[which(Meimi.DEG$gene.id == orthogroup.interest$Meimi[i]),]
  Tilwa.interest <- Tilwa.DEG[which(Tilwa.DEG$gene.id == orthogroup.interest$Tilwa[i]),]
  ##Check the statement to make sure you find the right orthogroup, as gene.id from orthogroup.interest may not be
  ##found in Ustma.DEG --> as a few genes were removed from the DGE analyses. If we don't find the orthogroup in Ustma.DEG
  ##exclude it from the analysis, go for next orthogroup
  if ( length(unique(Ustma.DEG$gene.id == orthogroup.interest$Ustma[i])) == 2 ) {    
    Ustma.interest <- Ustma.DEG[which(Ustma.DEG$gene.id == orthogroup.interest$Ustma[i]),]
  } else { next }
  
  ##Do nested logical statement --> if it is not DEG --> Species.FC = 0
  ##If it is DEG --> Species.FC = 1 or -1, depending on log2FoldChange
  ##For Ustma, there would be some genes having too low read counts, so DGE analysis is NA
  ##So need a statement for checking NA --> if yes --> exclude from the analysis (go for next round), if no --> assign as NA
  if ( is.na(Ustma.interest$padj) ) {
    next
  } else { 
    Ustma.FC <- NA
  }
  
  if (Meimi.interest$padj < 0.01) {
    if (Meimi.interest$log2FoldChange > 0) {
      Meimi.FC <- 1
      num.DE.Meimi  <- num.DE.Meimi+1
    } else { Meimi.FC <- -1; num.DE.Meimi <- num.DE.Meimi+1  }
  } else { Meimi.FC <- 0; num.nonDE.Meimi <- num.nonDE.Meimi+1 }
  if (Tilwa.interest$padj < 0.01) {
    if (Tilwa.interest$log2FoldChange > 0) {
      Tilwa.FC <- 1
      num.DE.Tilwa  <- num.DE.Tilwa+1
    } else { Tilwa.FC <- -1; num.DE.Tilwa  <- num.DE.Tilwa+1 }
  } else { Tilwa.FC <- 0; num.nonDE.Tilwa  <- num.nonDE.Tilwa+1 }

  if (Ustma.interest$padj < 0.01 & is.na(Ustma.FC)) {  ##A statement after checking NA on padj, Gene is checked if it is DE
    if (Ustma.interest$log2FoldChange > 0) {
      Ustma.FC <- 1
      num.DE.Ustma  <- num.DE.Ustma+1
    } else { Ustma.FC <- -1; num.DE.Ustma  <- num.DE.Ustma+1 }
  } else { Ustma.FC <- 0; num.nonDE.Ustma  <- num.nonDE.Ustma+1 }
  
  ##Finally, do a logical testing for concordance, conflict and non.DE
  ##If If all species have the same FC and they are DE --> rbind for concord data frame
  ##If all species have FC == 0 --> rbind for non.DE data frame
  ##If all are DE but not concurrent --> rbind for conflict data frame
  ##If 0 present in one of the analyzed species --> rbind for semi.non.DE
  if ( Meimi.FC == Tilwa.FC & Meimi.FC == Ustma.FC & ( Meimi.FC ) ){
    concord.DE.orthogroup <- rbind(concord.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                "Ustma", Ustma.interest))
    next
  }
  if ( Meimi.FC == Tilwa.FC & Meimi.FC == Ustma.FC & (Meimi.FC == 0) ) {
    non.DE.orthogroup <- rbind(non.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                        "Ustma", Ustma.interest))
    next
  }
  if ( ((Meimi.FC != Tilwa.FC) | (Meimi.FC != Ustma.FC) | (Ustma.FC != Tilwa.FC)) & 
       ( Meimi.FC & Tilwa.FC & Ustma.FC ) ) {
    conflict.DE.orthogroup <- rbind(conflict.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                  "Ustma", Ustma.interest))
    next
  }
  if ( (Meimi.FC == 0) | (Tilwa.FC == 0 ) | (Ustma.FC == 0 ) ){
    semi.non.DE.orthogroup <- rbind(semi.non.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                  "Ustma", Ustma.interest))
    next
  }
}

##Rearrange the dataset, sort by highest fold change genes, round the number and change colnames
colnames(concord.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                     "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                     "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(conflict.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                      "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                      "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(semi.non.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                      "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                      "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(non.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                 "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                 "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
##Check the content
num.DE.Meimi ;  num.nonDE.Meimi ;  num.DE.Tilwa ; num.nonDE.Tilwa; num.DE.Ustma ; num.nonDE.Ustma
nrow(concord.DE.orthogroup) ; nrow(non.DE.orthogroup) ; nrow(conflict.DE.orthogroup) ; nrow(semi.non.DE.orthogroup); nrow(orthogroup.interest)
##300 genes are missing --> These are probably missing probes from microarray!
##Use a logical statement to check each section in the Venn Diagram
##Section of DE in Meimi and Tilwa, but non.DE in Ustma
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.padj < 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj >= 0.01,])
##Check concordant/conflict genes by varying a statement
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.padj < 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj >= 0.01 & semi.non.DE.orthogroup$Meimi.log2FC > 0 &
                              semi.non.DE.orthogroup$Tilwa.log2FC > 0,])
##Section of DE in Ustma and Tilwa, but non.DE in Meimi
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj >= 0.01 & semi.non.DE.orthogroup$Tilwa.padj < 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj < 0.01,])
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj >= 0.01 & semi.non.DE.orthogroup$Tilwa.padj < 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.log2FC > 0 &
                              semi.non.DE.orthogroup$Ustma.log2FC > 0,])
##Section of DE in Ustma and Meimi, but non.DE in Tilwa
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.padj >= 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj < 0.01,])
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.padj >= 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.log2FC > 0 &
                              semi.non.DE.orthogroup$Ustma.log2FC > 0,])
##Section of only DE in one species
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj >= 0.01 & semi.non.DE.orthogroup$Tilwa.padj >= 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj < 0.01,])
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.01 & semi.non.DE.orthogroup$Tilwa.padj >= 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj >= 0.01,])
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj >= 0.01 & semi.non.DE.orthogroup$Tilwa.padj < 0.01 &
                              semi.non.DE.orthogroup$Ustma.padj >= 0.01,])
##Round the number before writing tables
colnames(concord.DE.orthogroup)
concord.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)] <- round(concord.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)], digits = 4)
conflict.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)] <- round(conflict.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)], digits = 4)
non.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)] <- round(non.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)], digits = 4)
semi.non.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)] <- round(semi.non.DE.orthogroup[,c(3,4,5,8,9,10,13,14,15)], digits = 4)

##Write the results
write.table(concord.DE.orthogroup, file="Ustilaginomycotina_concordantGenes.txt", sep="\t", quote=FALSE)
write.table(conflict.DE.orthogroup, file="Ustilaginomycotina_conflictGenes.txt", sep="\t", quote=FALSE)
write.table(non.DE.orthogroup, file="Ustilaginomycotina_nonDEGenes.txt", sep="\t", quote=FALSE)
write.table(semi.non.DE.orthogroup, file="Ustilaginomycotina_SeminonDGenes.txt", sep="\t", quote=FALSE)

#####Compare between two Ophnu datasets (Nigg et al. 2015 and 2016)#####
concord.DE.orthogroup <- data.frame()
conflict.DE.orthogroup <- data.frame()
semi.non.DE.orthogroup <- data.frame()
non.DE.orthogroup <- data.frame()
num.DE.Ophnu2 <- 0
num.nonDE.Ophnu2 <- 0
num.DE.Ophnu <- 0
num.nonDE.Ophnu <- 0
##orthogroup.interest in this case would be Ustma gene id
orthogroup.interest <- read.csv("../OrthoFinder_Jan2019/Ophnu_gene_id_v1Apr2019.txt", header=TRUE)
orthogroup.interest <- orthogroup.interest$ProteinId
for ( i in 1:length(orthogroup.interest) ) {
  ##We need logical variables for FC (+, - or 0)
  Ophnu.FC <- vector()
  Ophnu2.FC <- vector()
  
  ##Check the statement to make sure you find the right orthogroup, as gene.id from orthogroup.interest may not be
  ##found in Ophnu.DEG2 --> as a few genes were removed from the DGE analyses. If we don't find the orthogroup in Ophnu.DEG2
  ##exclude it from the analysis, go for next orthogroup
  if ( length(unique(Ophnu.DEG2$gene.id == orthogroup.interest[i])) == 2 ) {    
    Ophnu2.interest <- Ophnu.DEG2[which(Ophnu.DEG2$gene.id == orthogroup.interest[i]),]
  } else { next }
  ##Same thing for Ophnu
  if ( length(unique(Ophnu.DEG$gene.id == orthogroup.interest[i])) == 2 ) {    
    Ophnu.interest <- Ophnu.DEG[which(Ophnu.DEG$gene.id == orthogroup.interest[i]),]
  } else { next }
  
  ##Do nested logical statement --> if it is not DEG --> Species.FC = 0
  ##If it is DEG --> Species.FC = 1 or -1, depending on log2FoldChange
  ##For Ustma, there would be some genes having too low read counts, so DGE analysis is NA
  ##So need a statement for checking NA --> if yes --> exclude from the analysis (go for next round), if no --> assign as NA
  if ( is.na(Ophnu2.interest$padj) ) {
    next
  } else { 
    Ophnu2.FC <- NA
  }
  ##Same thing for Ophnu
  if ( is.na(Ophnu.interest$padj) ) {
    next
  } else { 
    Ophnu.FC <- NA
  }
  if (Ophnu2.interest$padj < 0.01 & is.na(Ophnu2.FC)) {  ##A statement after checking NA on padj, Gene is checked if it is DE
    if (Ophnu2.interest$log2FoldChange > 0) {
      Ophnu2.FC <- 1
      num.DE.Ophnu2  <- num.DE.Ophnu2+1
    } else { Ophnu2.FC <- -1; num.DE.Ophnu2  <- num.DE.Ophnu2+1 }
  } else { Ophnu2.FC <- 0; num.nonDE.Ophnu2  <- num.nonDE.Ophnu2+1 }
  if (Ophnu.interest$padj < 0.01 & is.na(Ophnu.FC)) {  ##A statement after checking NA on padj, Gene is checked if it is DE
    if (Ophnu.interest$log2FoldChange > 0) {
      Ophnu.FC <- 1
      num.DE.Ophnu  <- num.DE.Ophnu+1
    } else { Ophnu.FC <- -1; num.DE.Ophnu  <- num.DE.Ophnu+1 }
  } else { Ophnu.FC <- 0; num.nonDE.Ophnu  <- num.nonDE.Ophnu+1 }
  
  ##Finally, do a logical testing for concordance, conflict and non.DE
  ##If If all species have the same FC and they are DE --> rbind for concord data frame
  ##If all species have FC == 0 --> rbind for non.DE data frame
  ##If all are DE but not concurrent --> rbind for conflict data frame
  ##If 0 present in one of the analyzed species --> rbind for semi.non.DE
  if ( Ophnu2.FC == Ophnu.FC & (Ophnu2.FC != 0) ){
    concord.DE.orthogroup <- rbind(concord.DE.orthogroup, cbind("Ophnu2", Ophnu2.interest, "Ophnu", Ophnu.interest))
    next
  }
  if ( Ophnu2.FC == Ophnu.FC & (Ophnu2.FC == 0) ) {
    non.DE.orthogroup <- rbind(non.DE.orthogroup, cbind("Ophnu2", Ophnu2.interest, "Ophnu", Ophnu.interest))
    next
  }
  if ( (Ophnu2.FC != Ophnu.FC) & ( Ophnu2.FC & Ophnu.FC ) ) {
    conflict.DE.orthogroup <- rbind(conflict.DE.orthogroup, cbind("Ophnu2", Ophnu2.interest, "Ophnu", Ophnu.interest))
    next
  }
  if ( (Ophnu2.FC == 0) | (Ophnu.FC == 0 ) ){
    semi.non.DE.orthogroup <- rbind(semi.non.DE.orthogroup, cbind("Ophnu2", Ophnu2.interest, "Ophnu", Ophnu.interest))
    next
  }
}

##Rearrange the dataset, sort by highest fold change genes, round the number and change colnames
colnames(concord.DE.orthogroup) <- c("Ophnu2.sp", "Ophnu2.gene.id", "Ophnu2.log2FC", "Ophnu2.padj", "Ophnu.sp",
                                     "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.padj")
colnames(conflict.DE.orthogroup) <- c("Ophnu2.sp", "Ophnu2.gene.id", "Ophnu2.log2FC", "Ophnu2.padj", "Ophnu.sp",
                                      "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.padj")
colnames(semi.non.DE.orthogroup) <- c("Ophnu2.sp", "Ophnu2.gene.id", "Ophnu2.log2FC", "Ophnu2.padj", "Ophnu.sp",
                                      "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.padj")
colnames(non.DE.orthogroup) <- c("Ophnu2.sp", "Ophnu2.gene.id", "Ophnu2.log2FC", "Ophnu2.padj", "Ophnu.sp",
                                 "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.padj")
##Check the content
num.DE.Ophnu2 ;  num.nonDE.Ophnu2 ;  num.DE.Ophnu ; num.nonDE.Ophnu
nrow(concord.DE.orthogroup) ; nrow(non.DE.orthogroup) ; nrow(conflict.DE.orthogroup) ; nrow(semi.non.DE.orthogroup); length(orthogroup.interest)

##Write the results
write.table(concord.DE.orthogroup, file="Nigg2015and2016_concordantGenes.txt", sep="\t", quote=FALSE)
write.table(conflict.DE.orthogroup, file="Nigg2015and2016_conflictGenes.txt", sep="\t", quote=FALSE)
write.table(non.DE.orthogroup, file="Nigg2015and2016_nonDEGenes.txt", sep="\t", quote=FALSE)
write.table(semi.non.DE.orthogroup, file="Nigg2015and2016_SeminonDGenes.txt", sep="\t", quote=FALSE)


#####Compare between four species: Meimi, Tilwa, Ustma, Ophnu #####
##Four species comparison --> use p < 0.05 cutoff to make it more inclusive
concord.DE.orthogroup <- data.frame()
conflict.DE.orthogroup <- data.frame()
semi.non.DE.orthogroup <- data.frame()
non.DE.orthogroup <- data.frame()
num.DE.Meimi <- 0; num.nonDE.Meimi <- 0; num.DE.Tilwa <- 0; num.nonDE.Tilwa <- 0
num.DE.Ustma <- 0; num.nonDE.Ustma <- 0; num.DE.Ophnu <- 0; num.nonDE.Ophnu <- 0
orthogroup.interest <- orthogroup.table[orthogroup.table$Tilwa > 0 & orthogroup.table$Meimi > 0 & orthogroup.table$Ophnu > 0 &
                                          orthogroup.table$Ustma > 0,-1]
for ( i in 1:nrow(orthogroup.interest) ) {
  ##We need logical variables for FC (+, - or 0)
  Meimi.FC <- vector()
  Tilwa.FC <- vector()
  Ophnu.FC <- vector()
  Ustma.FC <- vector()
  ##Then, extract orthogroup of interest
  Meimi.interest <- Meimi.DEG[which(Meimi.DEG$gene.id == orthogroup.interest$Meimi[i]),]
  Tilwa.interest <- Tilwa.DEG[which(Tilwa.DEG$gene.id == orthogroup.interest$Tilwa[i]),]
  ##Check the statement to make sure you find the right orthogroup, as gene.id from orthogroup.interest may not be
  ##found in Ophnu.DEG --> as a few genes were removed from the DGE analyses. If we don't find the orthogroup in Ophnu.DEG
  ##exclude it from the analysis, go for next orthogroup
  if ( length(unique(Ophnu.DEG$gene.id == orthogroup.interest$Ophnu[i])) == 2 ) {    
    Ophnu.interest <- Ophnu.DEG[which(Ophnu.DEG$gene.id == orthogroup.interest$Ophnu[i]),]
  } else { next }
  ##Same thing for Ustma
  if ( length(unique(Ustma.DEG$gene.id == orthogroup.interest$Ustma[i])) == 2 ) {    
    Ustma.interest <- Ustma.DEG[which(Ustma.DEG$gene.id == orthogroup.interest$Ustma[i]),]
  } else { next }
  ##Do nested logical statement --> if it is not DEG --> Species.FC = 0
  ##If it is DEG --> Species.FC = 1 or -1, depending on log2FoldChange
  ##For Ophnu, there would be some genes having too low read counts, so DGE analysis is NA
  ##So need a statement for checking NA --> if yes --> exclude from the analysis (go for next round), if no --> assign as NA
  if ( is.na(Ophnu.interest$padj) ) {
    next
  } else { 
    Ophnu.FC <- NA
  }
  if ( is.na(Ustma.interest$padj) ) {
    next
  } else { 
    Ustma.FC <- NA
  }
  if ( is.na(Tilwa.interest$padj) ) {
    next
  } else { 
    Tilwa.FC <- NA
  }
  if ( is.na(Meimi.interest$padj) ) {
    next
  } else { 
    Meimi.FC <- NA
  }
  
  if (Meimi.interest$padj < 0.05) {
    if (Meimi.interest$log2FoldChange > 0) {
      Meimi.FC <- 1
      num.DE.Meimi  <- num.DE.Meimi+1
    } else { Meimi.FC <- -1; num.DE.Meimi <- num.DE.Meimi+1  }
  } else { Meimi.FC <- 0; num.nonDE.Meimi <- num.nonDE.Meimi+1 }
  if (Tilwa.interest$padj < 0.05) {
    if (Tilwa.interest$log2FoldChange > 0) {
      Tilwa.FC <- 1
      num.DE.Tilwa  <- num.DE.Tilwa+1
    } else { Tilwa.FC <- -1; num.DE.Tilwa  <- num.DE.Tilwa+1 }
  } else { Tilwa.FC <- 0; num.nonDE.Tilwa  <- num.nonDE.Tilwa+1 }
  
  if (Ophnu.interest$padj < 0.05 & is.na(Ophnu.FC)) {  ##A statement after checking NA on padj, Gene is checked if it is DE
    if (Ophnu.interest$log2FoldChange > 0) {
      Ophnu.FC <- 1
      num.DE.Ophnu  <- num.DE.Ophnu+1
    } else { Ophnu.FC <- -1; num.DE.Ophnu  <- num.DE.Ophnu+1 }
  } else { Ophnu.FC <- 0; num.nonDE.Ophnu  <- num.nonDE.Ophnu+1 }
  if (Ustma.interest$padj < 0.05 & is.na(Ustma.FC)) {  ##A statement after checking NA on padj, Gene is checked if it is DE
    if (Ustma.interest$log2FoldChange > 0) {
      Ustma.FC <- 1
      num.DE.Ustma  <- num.DE.Ustma+1
    } else { Ustma.FC <- -1; num.DE.Ustma  <- num.DE.Ustma+1 }
  } else { Ustma.FC <- 0; num.nonDE.Ustma  <- num.nonDE.Ustma+1 }
  ##Finally, do a logical testing for concordance, conflict and non.DE
  ##If If all species have the same FC and they are DE --> rbind for concord data frame
  ##If all species have FC == 0 --> rbind for non.DE data frame
  ##If all are DE but not concurrent --> rbind for conflict data frame
  ##If 0 present in one of the analyzed species --> rbind for semi.non.DE
  if ( Meimi.FC == Tilwa.FC & Meimi.FC == Ophnu.FC & Meimi.FC == Ustma.FC & ( Meimi.FC ) ){
    concord.DE.orthogroup <- rbind(concord.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                "Ophnu", Ophnu.interest, "Ustma", Ustma.interest))
    next
  }
  if ( Meimi.FC == Tilwa.FC & Meimi.FC == Ophnu.FC & Meimi.FC == Ustma.FC & (Meimi.FC == 0) ) {
    non.DE.orthogroup <- rbind(non.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                        "Ophnu", Ophnu.interest, "Ustma", Ustma.interest))
    next
  }
  if ( ((Meimi.FC != Tilwa.FC) | (Meimi.FC != Ophnu.FC) | (Meimi.FC != Ustma.FC) | (Ophnu.FC != Tilwa.FC) | (Ophnu.FC != Ustma.FC) |
        (Tilwa.FC != Ustma.FC)) &  ( Meimi.FC & Tilwa.FC & Ophnu.FC & Ustma.FC ) ) {
    conflict.DE.orthogroup <- rbind(conflict.DE.orthogroup,  cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                   "Ophnu", Ophnu.interest, "Ustma", Ustma.interest))
    next
  }
  if ( (Meimi.FC == 0) | (Tilwa.FC == 0 ) | (Ophnu.FC == 0 ) | (Ustma.FC == 0 ) ){
    semi.non.DE.orthogroup <- rbind(semi.non.DE.orthogroup, cbind("Meimi", Meimi.interest, "Tilwa", Tilwa.interest,
                                                                  "Ophnu", Ophnu.interest, "Ustma", Ustma.interest))
    next
  }
}

##Rearrange the dataset, sort by highest fold change genes, round the number and change colnames
colnames(concord.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                     "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                     "Ophnu.sp", "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.pvalue", "Ophnu.padj", 
                                     "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(conflict.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                      "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                      "Ophnu.sp", "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.pvalue", "Ophnu.padj", 
                                      "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(semi.non.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                      "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                      "Ophnu.sp", "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.pvalue", "Ophnu.padj", 
                                      "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
colnames(non.DE.orthogroup) <- c("Meimi.sp", "Meimi.gene.id", "Meimi.log2FC", "Meimi.pvalue", "Meimi.padj", 
                                 "Tilwa.sp", "Tilwa.gene.id", "Tilwa.log2FC", "Tilwa.pvalue", "Tilwa.padj", 
                                 "Ophnu.sp", "Ophnu.gene.id", "Ophnu.log2FC", "Ophnu.pvalue", "Ophnu.padj", 
                                 "Ustma.sp", "Ustma.gene.id", "Ustma.log2FC", "Ustma.pvalue", "Ustma.padj")
##Check the content
num.DE.Meimi ;  num.nonDE.Meimi ;  num.DE.Tilwa ; num.nonDE.Tilwa; num.DE.Ophnu ; num.nonDE.Ophnu; num.DE.Ustma ; num.nonDE.Ustma
nrow(concord.DE.orthogroup) ; nrow(non.DE.orthogroup) ; nrow(conflict.DE.orthogroup) ; nrow(semi.non.DE.orthogroup); nrow(orthogroup.interest)
##Use a logical statement to check each section in the Venn Diagram
##Section of DE in 3 species
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.05 & semi.non.DE.orthogroup$Tilwa.padj < 0.05 &
                              semi.non.DE.orthogroup$Ophnu.padj < 0.05 & semi.non.DE.orthogroup$Ustma.padj >= 0.05,])
##Check concordant/conflict genes by varying a statement
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.05 & semi.non.DE.orthogroup$Tilwa.padj < 0.05 &
                              semi.non.DE.orthogroup$Ophnu.padj < 0.05 & semi.non.DE.orthogroup$Ustma.padj >= 0.05 & semi.non.DE.orthogroup$Meimi.log2FC > 0 &
                              semi.non.DE.orthogroup$Tilwa.log2FC > 0 & semi.non.DE.orthogroup$Ophnu.log2FC > 0,])

##Section of DE in 2 species
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.05 & semi.non.DE.orthogroup$Tilwa.padj < 0.05 &
                              semi.non.DE.orthogroup$Ophnu.padj >= 0.05 & semi.non.DE.orthogroup$Ustma.padj >= 0.05,])
##Check concordant/conflict genes by varying a statement
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.05 & semi.non.DE.orthogroup$Tilwa.padj < 0.05 &
                              semi.non.DE.orthogroup$Ophnu.padj >= 0.05 & semi.non.DE.orthogroup$Ustma.padj >= 0.05 &
                              semi.non.DE.orthogroup$Meimi.log2FC > 0 & semi.non.DE.orthogroup$Tilwa.log2FC > 0,])

##Section of only DE in one species
nrow(semi.non.DE.orthogroup[semi.non.DE.orthogroup$Meimi.padj < 0.05 & semi.non.DE.orthogroup$Tilwa.padj >= 0.05 &
                              semi.non.DE.orthogroup$Ophnu.padj >= 0.05 & semi.non.DE.orthogroup$Ustma.padj >= 0.05,])
##Write the results
write.table(concord.DE.orthogroup, file="FourSpeciesNigg2015Ustma_concordantGenes.txt", sep="\t", quote=FALSE)
write.table(conflict.DE.orthogroup, file="FourspeciesNigg2015Ustma_conflictGenes.txt", sep="\t", quote=FALSE)
write.table(non.DE.orthogroup, file="FourspeciesNigg2015Ustma_nonDEGenes.txt", sep="\t", quote=FALSE)
write.table(semi.non.DE.orthogroup, file="FourspeciesNigg2015Ustma_SeminonDGenes.txt", sep="\t", quote=FALSE)



#####Try to plot concord.DEG from Ustilaginomycotina on other Ustma mva plots #####
##Load orthogroup.table
##First, load the concord.DEG resulted from Ustilaginomycotina
orthogroup.table <- read.csv("../OrthoFinder_Jan2019/Single_copy_orthogroups_FiveSpecies_v1Jan2019.txt",
                             sep = "\t", header = TRUE)
orthogroup.interest <- orthogroup.table[orthogroup.table$Tilwa > 0 & orthogroup.table$Meimi > 0 & orthogroup.table$Ustma > 0,c(3,5,6)]
Ustilaginomycotina.concord.DEG <- read.csv("../CompRNASeq_Results_v2_Apr2019/Ustilaginomycotina_concordantGenes.txt", sep="\t", header=TRUE)
##Then, subset only Ustilaginomycotina orthogroups that are DE in Meimi and Tilwa
nrow(Ustilaginomycotina.concord.DEG)
Ustma.id.interest <- Ustilaginomycotina.concord.DEG[,12:13]
head(Ustma.id.interest)

##Then, read Ustma DESeq2 results --> do MVA plot, and then we plot some data point of interest
## Start from Tollot et al. 2016 study ##
Ustma.DESeq.result <- read.csv("../Umaydis/Tollot2016/Results_v1/Tollot2016_DESeq2ResultsStats.txt", header=TRUE)
##Set gene.id as a row name
rownames(Ustma.DESeq.result) <- Ustma.DESeq.result[,1]
Ustma.DESeq.result <- Ustma.DESeq.result[,-1]
head(Ustma.DESeq.result)
##data point in the MVA plot: black is normal gene, and red is significant gene
  gene.color <- rep.int(1, times=nrow(Ustma.DESeq.result))
  gene.color[which(Ustma.DESeq.result$padj < 0.05)] <- 2
##Perform MVA plot
  plot(Ustma.DESeq.result$baseMean, Ustma.DESeq.result$log2FoldChange, cex=0.3, col=gene.color, log="x",
       xlab="Mean Expression", ylab="logFC", ylim=c(-6,6))
  plot(Ustma.DESeq.result$baseMean, Ustma.DESeq.result$log2FoldChange, type="n", cex=0.3, col=gene.color, log="x",
       xlab="Mean Expression", ylab="logFC", ylim=c(-6,6), main="Tollot et al. 2016")
  abline(h=c(-0.5,0.5),col="red",lwd=2)
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.DESeq.result) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Should I consider only genes having fold change more than 0.5?? --> likely to be DE but having too few read counts
  if ( Ustma.DESeq.result$log2FoldChange[interest.point] < 0.5 & Ustma.DESeq.result$log2FoldChange[interest.point] > -0.5 ) { next }
  ##Plot a data point
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset
    points(log(Ustma.DESeq.result$baseMean[interest.point]), Ustma.DESeq.result$log2FoldChange[interest.point], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(log(Ustma.DESeq.result$baseMean[interest.point]), Ustma.DESeq.result$log2FoldChange[interest.point], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. Ustma.DESeq.result$log2FoldChange > 0.5 or -0.5 as a cutoff that
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & Ustma.DESeq.result$log2FoldChange[interest.point] > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & Ustma.DESeq.result$log2FoldChange[interest.point] < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                Ustma.DESeq.result$log2FoldChange[interest.point]))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 Ustma.DESeq.result$log2FoldChange[interest.point]))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##25 genes
conflict.num  ##9 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.Tollot.concord <- Ustilaginomycotina.concord.OG
Ustilago.Tollot.conflict <- Ustilaginomycotina.conflict.OG

##Then, go for Lanver et al. 2018 study
Ustma.DESeq.result <- read.csv("../Umaydis/Lanver2018/Results_v1/Lanver2018_DESeq2ResultsStats.txt", header=TRUE)
##Set gene.id as a row name
rownames(Ustma.DESeq.result) <- Ustma.DESeq.result[,1]
Ustma.DESeq.result <- Ustma.DESeq.result[,-1]
head(Ustma.DESeq.result)
##data point in the MVA plot: black is normal gene, and red is significant gene
  gene.color <- rep.int(1, times=nrow(Ustma.DESeq.result))
  gene.color[which(Ustma.DESeq.result$padj < 0.05)] <- 2
##Perform MVA plot
  plot(Ustma.DESeq.result$baseMean, Ustma.DESeq.result$log2FoldChange, cex=0.3, col=gene.color, log="x")
  plot(Ustma.DESeq.result$baseMean, Ustma.DESeq.result$log2FoldChange, cex=0.3, col=gene.color, log="x", type="n", main="Lanver et al. 2018",
       xlab="Mean Expression", ylab="logFC")
  abline(h=c(-0.5,0.5),col="red",lwd=2)
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.DESeq.result) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Should I consider only genes having fold change more than 0.5?? --> likely to be DE but having too few read counts
  if ( Ustma.DESeq.result$log2FoldChange[interest.point] < 0.5 & Ustma.DESeq.result$log2FoldChange[interest.point] > -0.5 ) { next }
  ##Plot a data point
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset
    points(log(Ustma.DESeq.result$baseMean[interest.point]), Ustma.DESeq.result$log2FoldChange[interest.point], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(log(Ustma.DESeq.result$baseMean[interest.point]), Ustma.DESeq.result$log2FoldChange[interest.point], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. Ustma.DESeq.result$log2FoldChange > 0.5 or -0.5 as a cutoff that
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & Ustma.DESeq.result$log2FoldChange[interest.point] > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & Ustma.DESeq.result$log2FoldChange[interest.point] < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                Ustma.DESeq.result$log2FoldChange[interest.point]))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 Ustma.DESeq.result$log2FoldChange[interest.point]))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##20 genes
conflict.num  ##28 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.Lanver.concord <- Ustilaginomycotina.concord.OG
Ustilago.Lanver.conflict <- Ustilaginomycotina.conflict.OG

#####Overlay DEG on rocketship plots #####
## Now, try overlay concord.DEG with Paul et al. 2018 study ##
Ustma.NormreadCount <- read.csv("../Umaydis/Paul2018/Paul2018_NormalizedReadCount.txt", header=TRUE)
##Set gene.id as a row name
rownames(Ustma.NormreadCount) <- Ustma.NormreadCount[,1]
Ustma.NormreadCount <- Ustma.NormreadCount[,-1]
head(Ustma.NormreadCount)
##These are normalized read counts --> do a rocketship plot. Start from between wtHighN and wtLowN
  plot( 1+Ustma.NormreadCount[,c(1,2)], col="#00000020", pch=20, cex=0.3, log="xy", type="n", main="Paul et al. 2014" )
## Plot a line showing log2FC more than 0.5
  x<-c(1,10,100,1000,10000,100000,1000000,10000000)
  y.up <- x*(2^0.5)
  lines(x, y.up, col="red")
  y.down <- x*(2^-0.5)
  lines(x, y.down, col="red")
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.NormreadCount) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Calculate fold change by division
  logFC.interest <- log(Ustma.NormreadCount[interest.point, 2] / Ustma.NormreadCount[interest.point, 1], base=2)
  ##Consider only genes having fold change more than 0.5. If not, ignore it
  if ( logFC.interest > -0.5 & logFC.interest < 0.5 ) { next }
  ##Plot a data point. Carefully check which should be in which axis
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset, e.g. |log2FC(y/x)| > 0.5 
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 2], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 2], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. FC.interest > 0.5 or -0.5 as a cutoff in a previous statement
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & logFC.interest > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & logFC.interest < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                logFC.interest))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 logFC.interest))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##37 genes
conflict.num  ##11 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.PaulN.concord <- Ustilaginomycotina.concord.OG
Ustilago.PaulN.conflict <- Ustilaginomycotina.conflict.OG

##Now, do the same thing between wtHighN and OverUmp2HighN
plot( 1+Ustma.NormreadCount[,c(1,3)], col="#00000020", pch=20, cex=0.3, log="xy", type="n", main="Paul et al. 2014" )
## Plot a line showing log2FC more than 0.5
lines(x, y.up, col="red")
lines(x, y.down, col="red")
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.NormreadCount) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Calculate fold change by division
  logFC.interest <- log(Ustma.NormreadCount[interest.point, 3] / Ustma.NormreadCount[interest.point, 1], base=2)
  ##Consider only genes having fold change more than 0.5. If not, ignore it
  if ( logFC.interest > -0.5 & logFC.interest < 0.5 ) { next }
  ##Plot a data point. Carefully check which should be in which axis
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset, e.g. |log2FC(y/x)| > 0.5 
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 3], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 3], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. FC.interest > 0.5 or -0.5 as a cutoff in a previous statement
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & logFC.interest > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & logFC.interest < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                logFC.interest))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 logFC.interest))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##14 genes
conflict.num  ##10 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.PaulUmp2.concord <- Ustilaginomycotina.concord.OG
Ustilago.PaulUmp2.conflict <- Ustilaginomycotina.conflict.OG

##Then, go for Donaldson2017 study
Ustma.NormreadCount <- read.csv("../Umaydis/Donaldson2017/Donaldson2017_NormalizedReadCount.txt", header=TRUE)
##Set gene.id as a row name
rownames(Ustma.NormreadCount) <- Ustma.NormreadCount[,1]
Ustma.NormreadCount <- Ustma.NormreadCount[,-1]
head(Ustma.NormreadCount)
##These are normalized read counts --> do a rocketship plot. Start from between Haploid521 and Dikaryon
plot( 1+Ustma.NormreadCount[,c(1,3)], col="#00000020", xlim=c(1,100000), ylim=c(1,100000), pch=20, cex=0.3, log="xy", type="n", main="Donaldson et al. 2014" )
## Plot a line showing log2FC more than 0.5
x<-c(1,10,100,1000,10000,100000,1000000,10000000)
y.up <- x*(2^0.5)
lines(x, y.up, col="red")
y.down <- x*(2^-0.5)
lines(x, y.down, col="red")
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.NormreadCount) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Calculate fold change by division
  logFC.interest <- log(Ustma.NormreadCount[interest.point, 3] / Ustma.NormreadCount[interest.point, 1], base=2)
  ##Consider only genes having fold change more than 0.5. If not, ignore it
  if ( logFC.interest > -0.5 & logFC.interest < 0.5 ) { next }
  ##Plot a data point. Carefully check which should be in which axis
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset, e.g. |log2FC(y/x)| > 0.5 
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 3], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(Ustma.NormreadCount[interest.point, 1], Ustma.NormreadCount[interest.point, 3], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. FC.interest > 0.5 or -0.5 as a cutoff in a previous statement
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & logFC.interest > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & logFC.interest < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                logFC.interest))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 logFC.interest))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##18 genes
conflict.num  ##31 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.Dikaryon1.concord <- Ustilaginomycotina.concord.OG
Ustilago.Dikaryon1.conflict <- Ustilaginomycotina.conflict.OG

##Now, do the same thing between Haploid518 and Dikaryon
plot( 1+Ustma.NormreadCount[,c(2,3)], col="#00000020", xlim=c(1,100000), ylim=c(1,100000), pch=20, cex=0.3, log="xy", main="Donaldson et al. 2014", type="n" )
## Plot a line showing log2FC more than 0.5
lines(x, y.up, col="red")
lines(x, y.down, col="red")
##Run a loop to plot Ustma.id.interest (i.e. DE genes in Tilwa and Meimi)
concord.num <- 0; conflict.num <- 0  ## Store a record of concordance/conflict
Ustilaginomycotina.concord.OG <- data.frame(); Ustilaginomycotina.conflict.OG <- data.frame()
for ( i in 1:nrow(Ustma.id.interest) ) {
  ##Test if MeimiTilwa.DEG has an orthogroup with Ustma, if not --> go for the next one
  interest.point <- which(rownames(Ustma.NormreadCount) ==  Ustma.id.interest$Ustma.gene.id[i])
  ##Calculate fold change by division
  if (is.na(log(Ustma.NormreadCount[interest.point, 3] / Ustma.NormreadCount[interest.point, 2], base=2))) {next}
  logFC.interest <- log(Ustma.NormreadCount[interest.point, 3] / Ustma.NormreadCount[interest.point, 2], base=2)
  ##Consider only genes having fold change more than 0.5. If not, ignore it
  if ( logFC.interest > -0.5 & logFC.interest < 0.5 ) { next }
  ##Plot a data point. Carefully check which should be in which axis
  if ( Ustma.id.interest$Ustma.log2FC[i] > 0 ){  ##goldenrod --> genes that are upregulated in concord dataset, e.g. |log2FC(y/x)| > 0.5 
    points(Ustma.NormreadCount[interest.point, 2], Ustma.NormreadCount[interest.point, 3], col="goldenrod1", cex=0.6, pch=16)
  }
  else { ##blue --> genes that are downregulated in concord dataset
    points(Ustma.NormreadCount[interest.point, 2], Ustma.NormreadCount[interest.point, 3], col="blue", cex=0.6, pch=16)
  }
  ##Check and count concordance, and store the info of concordance/conflict. FC.interest > 0.5 or -0.5 as a cutoff in a previous statement
  ##these genes are possibly to be DE
  if ((Ustma.id.interest$Ustma.log2FC[i] > 0 & logFC.interest > 0) | (Ustma.id.interest$Ustma.log2FC[i] < 0 & logFC.interest < 0)) {
    concord.num <- concord.num + 1
    Ustilaginomycotina.concord.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                logFC.interest))
  }
  else {
    conflict.num <- conflict.num + 1
    Ustilaginomycotina.conflict.OG <- rbind(Ustilaginomycotina.concord.OG, cbind(orthogroup.interest[orthogroup.interest$Ustma == Ustma.id.interest$Ustma.gene.id[i],],
                                                                                 logFC.interest))
  }
}
legend("bottomright", col=c("goldenrod1", "blue"), legend = c("presumably up", "presumably down"), pch=16, cex=0.8)
concord.num   ##25 genes
conflict.num  ##28 genes
colnames(Ustilaginomycotina.concord.OG)[4] <- "log2FC.Ustma"
colnames(Ustilaginomycotina.conflict.OG)[4] <- "log2FC.Ustma"
Ustilago.Dikaryon2.concord <- Ustilaginomycotina.concord.OG
Ustilago.Dikaryon2.conflict <- Ustilaginomycotina.conflict.OG
intersect(Ustilago.Dikaryon1.concord$Ustma, Ustilago.Dikaryon2.concord$Ustma)

##### Make a summary table among a few Ustma datasets #####
all.Ustma.concord <- sort(unique(c(Ustilago.Dikaryon1.concord$Ustma,Ustilago.Dikaryon2.concord$Ustma,Ustilago.PaulN.concord$Ustma,
                        Ustilago.PaulUmp2.concord$Ustma,Ustilago.Tollot.concord$Ustma,Ustilago.Lanver.concord$Ustma)))
##Make a data frame: rows are gene names and columns are set of studies. Fill the value of 0/1 for discordance/concordance
##to MeimiTilwa.concord.DEG
studies.summary <- data.frame(Tollot=rep(0, times=length(all.Ustma.concord)), Lanver=0, PaulN=0, PaulUmp2=0,
                              Dikaryon1=0, Dikaryon2=0, row.names = all.Ustma.concord)
##Use a loop to fill in info
for(i in 1:length(all.Ustma.concord)) {
  ##Use if statement to find if all.Ustma.concord[i] is found in each UStilago.concord
  if ( length(unique(Ustilago.Tollot.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$Tollot[i] <- 1
  }
  ##Do same thing with others
  if ( length(unique(Ustilago.Lanver.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$Lanver[i] <- 1
  }
  if ( length(unique(Ustilago.PaulN.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$PaulN[i] <- 1
  }
  if ( length(unique(Ustilago.PaulUmp2.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$PaulUmp2[i] <- 1
  }
  if ( length(unique(Ustilago.Dikaryon1.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$Dikaryon1[i] <- 1
  }
  if ( length(unique(Ustilago.Dikaryon2.concord$Ustma == all.Ustma.concord[i])) == 2 ) {  ##Means having TRUE and FALSE
    studies.summary$Dikaryon2[i] <- 1
  }
}
write.table(studies.summary, file="Ustilago_concordance_summary.txt", sep="\t", quote=FALSE)

##Then, recruit the othergroup info
orthogroup.interest <- data.frame()
for (i in 1:length(all.Ustma.concord)) {
  orthogroup.interest <- rbind(orthogroup.interest, orthogroup.table[which(orthogroup.table$Ustma == all.Ustma.concord[i]),c(3,5,6)])
}

Ustma.eggNOG <- read.csv("../OrthoFinder_Jan2019/eggNOG annotation/Ustma2_eggNOGformatted.txt", sep="\t", header=TRUE)
Ustma.DE.eggNOG <- data.frame()
##Work as a loop to add-on the eggNOG info for each of Ustma DEG list
for ( i in 1:nrow(orthogroup.interest) ) {
  Ustma.DE.eggNOG <- rbind(Ustma.DE.eggNOG, Ustma.eggNOG[Ustma.eggNOG$ProteinId == orthogroup.interest$Ustma[i],c(1:4,6)])
}
nrow(Ustma.DE.eggNOG)
write.table(Ustma.DE.eggNOG, file="Ustma_DEG_eggNOG.txt", sep="\t", quote=FALSE)
